Repository: flex-flexunit
Updated Branches:
  refs/heads/develop a2e850699 -> c8680a98f


fix up script to match Flexuint not Flex


Project: http://git-wip-us.apache.org/repos/asf/flex-flexunit/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-flexunit/commit/a32c4fca
Tree: http://git-wip-us.apache.org/repos/asf/flex-flexunit/tree/a32c4fca
Diff: http://git-wip-us.apache.org/repos/asf/flex-flexunit/diff/a32c4fca

Branch: refs/heads/develop
Commit: a32c4fcadc345c49e163902822d886c892bcb846
Parents: a2e8506
Author: Justin Mclean <[email protected]>
Authored: Mon Mar 17 09:07:36 2014 +1100
Committer: Justin Mclean <[email protected]>
Committed: Mon Mar 17 09:07:36 2014 +1100

----------------------------------------------------------------------
 build/deploy_release_candidate.sh | 26 +++++++++-----------------
 1 file changed, 9 insertions(+), 17 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-flexunit/blob/a32c4fca/build/deploy_release_candidate.sh
----------------------------------------------------------------------
diff --git a/build/deploy_release_candidate.sh 
b/build/deploy_release_candidate.sh
index 204d35a..848f223 100755
--- a/build/deploy_release_candidate.sh
+++ b/build/deploy_release_candidate.sh
@@ -22,15 +22,15 @@
 
 if [ $# -ne 2 ]
 then
-    echo "Usage: deploy_release_candidate flex_version ([0-99].[0-99].[0-999]) 
release_candidate ([0-100])"
+    echo "Usage: deploy_release_candidate flexunit_version 
([0-99].[0-99].[0-999]) release_candidate ([0-100])"
 fi
 
-FLEX_VERSION="$1"
-CHECK=`echo "$FLEX_VERSION" | grep -q -E '[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,3}$'`
+FLEXUNIT_VERSION="$1"
+CHECK=`echo "$FLEXUNIT_VERSION" | grep -q -E 
'[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,3}$'`
 
 if [ $? -ne 0 ]
 then
-       echo "Apache Flex version needs to be in the form [0-99].[0-99].[0-999]"
+       echo "Apache FlexUnit version needs to be in the form 
[0-99].[0-99].[0-999]"
        exit 1;
 fi
 
@@ -39,16 +39,15 @@ CHECK=`echo "$RELEASE_CANDIDATE" | grep -q -E '[0-9]{1,2}'`
 
 if [ $? -ne 0 ]
 then
-       echo "Apache Flex release candidate to be in the range 1-99"
+       echo "Apache FlexUnit release candidate to be in the range 1-99"
        exit 1;
 fi
 
 # Assumes FLEX_DEV_AREA has been set up and point to SVN checked out dev area
area
 
-VERSION_DIR="${FLEX_DEV_AREA}/sdk/${FLEX_VERSION}"
-RC_DIR="${FLEX_DEV_AREA}/sdk/${FLEX_VERSION}/rc${RELEASE_CANDIDATE}"
-BIN_DIR="${FLEX_DEV_AREA}/sdk/${FLEX_VERSION}/rc${RELEASE_CANDIDATE}/binaries"
-DOC_DIR="${FLEX_DEV_AREA}/sdk/${FLEX_VERSION}/rc${RELEASE_CANDIDATE}/docs"
+VERSION_DIR="${FLEXUNIT_DEV_AREA}/flexunit/${FLEXUNIT_VERSION}"
+RC_DIR="${FLEXUNIT_DEV_AREA}/flexunit/${FLEXUNIT_VERSION}/rc${RELEASE_CANDIDATE}"
+BIN_DIR="${FLEXUNIT_DEV_AREA}/flexunit/${FLEXUNIT_VERSION}/rc${RELEASE_CANDIDATE}/binaries"
 
 echo "RC directory is ${RC_DIR}"
 
@@ -67,17 +66,10 @@ then
        mkdir "${BIN_DIR}"
 fi
 
-if [ ! -d "${DOC_DIR}" ]
-then
-       mkdir "${DOC_DIR}"
-fi
-
 cp README "${RC_DIR}"
 cp RELEASE_NOTES "${RC_DIR}"
 cp ./out/*-src.* "${RC_DIR}"
 cp ./out/*-bin.* "${BIN_DIR}"
-cp ./out/*-config.xml "${BIN_DIR}"
-cp ./out/*-asdocs.* "${DOC_DIR}"
 
 
 
@@ -39,16 +39,15 @@ CHECK=`echo "$RELEASE_CANDIDATE" | grep -q -E '[0-9]{1,2}'`
 fi
 
-# Assumes FLEX_DEV_AREA has been set up and point to SVN checked out dev area
+# Assumes FLEXUNIT_DEV_AREA has been set up and point to SVN checked out dev 
area
 

Reply via email to